@@ -14,11 +14,11 @@ class SentenceSplitterBase:
     def __init__(self):
         self.splitter = None
 
-    def split(self, document: str) -> List[str]:
+    def split(self, document: str, clean_sent: bool) -> List[str]:
         raise NotImplementedError
 
 
-class KssSentenceSplitter(SentenceSplitterBase):
+class KssV1SentenceSplitter(SentenceSplitterBase):
     def __init__(self):
         super().__init__()
         try:
@@ -26,16 +26,13 @@ class KssSentenceSplitter(SentenceSplitterBase):
             assert importlib_metadata.version("kss") == "1.3.1"
         except ImportError:
             logger.warning(
-                "You need to install kss to use KssSentenceSplitter \n"
-                "pip install cython\n"
-                "pip install kss==1.3.1\n"
+                "You need to install kss to use KssV1SentenceSplitter!\n"
+                ">>> pip install cython\n"
+                ">>> pip install kss==1.3.1\n"
             )
 
     def split(self, document: str, clean_sent: bool = False) -> List[str]:
-        if not clean_sent:
-            return self.splitter.split_sentences(document)
-        else:
-            cleaned_output = []
-            for sent in self.splitter.split_sentences(document):
-                cleaned_output.append(clean_sentence(sent))
-            return cleaned_output
+        sentences = self.splitter.split_sentences(document)
+        if clean_sent:
+            sentences = [clean_sentence(sent) for sent in sentences]
+        return sentences
